package
module
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Aug 20, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
const (
DefaultLeftDelim = "{{"
DefaultRightDelim = "}}"
)
File reads the file at path, expands it as a text/template, and returns the result.
type Option func(*options)
Option configures the expansion.
WithDelims sets the action delimiters. Empty values stand for the defaults.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.